@@ -4,7 +4,7 @@ from typing import Any, Dict
 
 from freqtrade.configuration import setup_utils_configuration
 from freqtrade.enums import RunMode
-from freqtrade.exceptions import OperationalException
+from freqtrade.exceptions import ConfigurationError, OperationalException
 
 
 logger = logging.getLogger(__name__)
@@ -34,9 +34,9 @@ def setup_analyze_configuration(args: Dict[str, Any], method: RunMode) -> Dict[s
                     btfile = Path(config['exportfilename'])
                     signals_file = f"{btfile.parent}/{btfile.stem}_signals.pkl"
                 else:
-                    raise OperationalException(f"{config['exportfilename']} does not exist.")
+                    raise ConfigurationError(f"{config['exportfilename']} does not exist.")
         else:
-            raise OperationalException('exportfilename not in config.')
+            raise ConfigurationError('exportfilename not in config.')
 
         if (not Path(signals_file).exists()):
             raise OperationalException(
