@@ -2,12 +2,12 @@ from typing import Any, Dict
 
 from freqtrade.configuration import setup_utils_configuration
 from freqtrade.enums import RunMode
-from freqtrade.exceptions import OperationalException
+from freqtrade.exceptions import ConfigurationError
 
 
 def validate_plot_args(args: Dict[str, Any]) -> None:
     if not args.get('datadir') and not args.get('config'):
-        raise OperationalException(
+        raise ConfigurationError(
             "You need to specify either `--datadir` or `--config` "
             "for plot-profit and plot-dataframe.")
 
