@@ -41,6 +41,7 @@ class VolumePairList(IPairList):
         self._number_pairs = self._pairlistconfig['number_assets']
         self._sort_key: Literal['quoteVolume'] = self._pairlistconfig.get('sort_key', 'quoteVolume')
         self._min_value = self._pairlistconfig.get('min_value', 0)
+        self._max_value = self._pairlistconfig.get("max_value", None)
         self._refresh_period = self._pairlistconfig.get('refresh_period', 1800)
         self._pair_cache: TTLCache = TTLCache(maxsize=1, ttl=self._refresh_period)
         self._lookback_days = self._pairlistconfig.get('lookback_days', 0)
@@ -139,6 +140,12 @@ class VolumePairList(IPairList):
                 "description": "Minimum value",
                 "help": "Minimum value to use for filtering the pairlist.",
             },
+            "max_value": {
+                "type": "number",
+                "default": None,
+                "description": "Maximum value",
+                "help": "Maximum value to use for filtering the pairlist.",
+            },
             **IPairList.refresh_period_parameter(),
             "lookback_days": {
                 "type": "number",
@@ -229,12 +236,8 @@ class VolumePairList(IPairList):
                 if p not in self._pair_cache
             ]
 
-            # Get all candles
-            candles = {}
-            if needed_pairs:
-                candles = self._exchange.refresh_latest_ohlcv(
-                    needed_pairs, since_ms=since_ms, cache=False
-                )
+            candles = self._exchange.refresh_ohlcv_with_cache(needed_pairs, since_ms)
+
             for i, p in enumerate(filtered_tickers):
                 contract_size = self._exchange.markets[p['symbol']].get('contractSize', 1.0) or 1.0
                 pair_candles = candles[
@@ -274,6 +277,9 @@ class VolumePairList(IPairList):
         if self._min_value > 0:
             filtered_tickers = [
                 v for v in filtered_tickers if v[self._sort_key] > self._min_value]
+        if self._max_value is not None:
+            filtered_tickers = [
+                v for v in filtered_tickers if v[self._sort_key] < self._max_value]
 
         sorted_tickers = sorted(filtered_tickers, reverse=True, key=lambda t: t[self._sort_key])
 
