@@ -77,9 +77,8 @@ class CryptoToFiatConverter(LoggingMixin):
                 return
             # If the request is not a 429 error we want to raise the normal error
             logger.error(
-                "Could not load FIAT Cryptocurrency map for the following problem: {}".format(
-                    request_exception
-                )
+                "Could not load FIAT Cryptocurrency map for the following problem: "
+                f"{request_exception}"
             )
         except (Exception) as exception:
             logger.error(
