@@ -1,6 +1,6 @@
 from freqtrade.util.datetime_helpers import (dt_floor_day, dt_from_ts, dt_humanize, dt_now, dt_ts,
-                                             dt_ts_def, dt_utc, format_date, format_ms_time,
-                                             shorten_date)
+                                             dt_ts_def, dt_ts_none, dt_utc, format_date,
+                                             format_ms_time, shorten_date)
 from freqtrade.util.formatters import decimals_per_coin, fmt_coin, round_value
 from freqtrade.util.ft_precise import FtPrecise
 from freqtrade.util.periodic_cache import PeriodicCache
@@ -14,6 +14,7 @@ __all__ = [
     'dt_now',
     'dt_ts',
     'dt_ts_def',
+    'dt_ts_none',
     'dt_utc',
     'format_date',
     'format_ms_time',
